@@ -3,5 +3,7 @@
  (lambda ()
    (LaTeX-add-bibitems
     "Rpack:bibtex"
-    "parseRd")))
+    "parseRd"
+    "Rdevtools"))
+ :bibtex)
 
