@@ -2,9 +2,9 @@
  "Inserting_bibtex_references"
  (lambda ()
    (TeX-add-to-alist 'LaTeX-provided-class-options
-                     '(("article" "12pt" "a4paper")))
+                     '(("jss" "a4paper" "twoside" "11pt" "nojss" "article")))
    (TeX-add-to-alist 'LaTeX-provided-package-options
-                     '(("natbib" "authoryear" "round" "longnamesfirst")))
+                     '(("fontenc" "T1") ("geometry" "left=2cm" "right=2cm" "bottom=15mm") ("natbib" "authoryear" "round" "longnamesfirst")))
    (add-to-list 'LaTeX-verbatim-environments-local "alltt")
    (add-to-list 'LaTeX-verbatim-macros-with-braces-local "hyperref")
    (add-to-list 'LaTeX-verbatim-macros-with-braces-local "hyperimage")
@@ -12,33 +12,29 @@
    (add-to-list 'LaTeX-verbatim-macros-with-braces-local "nolinkurl")
    (add-to-list 'LaTeX-verbatim-macros-with-braces-local "url")
    (add-to-list 'LaTeX-verbatim-macros-with-braces-local "path")
-   (add-to-list 'LaTeX-verbatim-macros-with-delims-local "url")
    (add-to-list 'LaTeX-verbatim-macros-with-delims-local "path")
    (TeX-run-style-hooks
     "latex2e"
-    "article"
-    "art12"
-    "a4wide"
+    "jss"
+    "jss11"
+    "fontenc"
+    "geometry"
     "graphicx"
     "color"
     "alltt"
     "natbib"
     "hyperref")
-   (TeX-add-symbols
-    '("email" 1)
-    "E"
-    "VAR"
-    "COV"
-    "p"
-    "ui"
-    "oi")
    (LaTeX-add-labels
-    "sec:devtools"
-    "sec:insert-refer-inter")
-   (LaTeX-add-environments
-    "smallexample")
-   (LaTeX-add-color-definecolors
-    "Red"
-    "Blue"
-    "hellgrau")))
+    "sec:org9882d46"
+    "sec:org9adc575"
+    "sec:orga68020b"
+    "sec:org6fdc184"
+    "sec:macros-citations"
+    "sec:org64e04c3"
+    "sec:changing-style-refer"
+    "sec:org8cc6961"
+    "sec:org9d8ff4c"
+    "sec:orgb3a9b6e"
+    "sec:org1f3fc7c"))
+ :latex)
 
